@@ -1,7 +1,8 @@
 module StringDistances
 
-using Distances
-import StatsAPI: pairwise, pairwise!
+using Distances: Distances, SemiMetric, Metric, evaluate, result_type
+using StatsAPI: StatsAPI, pairwise, pairwise!
+
 # Distances API
 abstract type StringSemiMetric <: SemiMetric end
 abstract type StringMetric <: Metric end
@@ -13,8 +14,6 @@ function Distances.result_type(dist::Union{StringSemiMetric, StringMetric}, s1::
     end
     return T
 end
-Distances.result_type(dist::Union{StringSemiMetric, StringMetric}, s1, s2) = result_type(dist, typeof(s1), typeof(s2))
-
 
 
 (dist::Union{StringSemiMetric, StringMetric})(s1, s2; max_dist = nothing) = dist(s1, s2)
